# LineJoy 小程序项目架构指南

本文档提供对 LineJoy 项目中 services 和 stores 目录的使用说明，旨在帮助开发者理解项目架构并促进协作开发。

## 目录

1. [整体架构](#整体架构)
2. [Services 服务层](#services-服务层)
3. [Stores 状态管理层](#stores-状态管理层)
4. [协同工作流程](#协同工作流程)
5. [扩展指南](#扩展指南)
6. [最佳实践](#最佳实践)

## 整体架构

LineJoy 项目采用了模块化的架构设计，主要分为以下几层：

- **Services 层**：负责与外部 API 通信、数据处理和核心业务逻辑
- **Stores 层**：使用 Pinia 管理应用状态，处理状态逻辑和组件间数据共享
- **Components 层**：UI 组件，消费 stores 中的状态
- **Pages 层**：页面组件，组合多个组件形成完整的页面

这种分层架构提供了清晰的职责分离和关注点分离，使代码更易维护和扩展。

## Services 服务层

服务层处理所有与外部系统的交互，包括 API 调用、云函数调用、本地存储等。

### 目录结构

```
src/services/
├── api/                # API 服务
│   ├── game.ts         # 游戏列表和详情 API
│   ├── room.ts         # 房间管理 API
│   └── games/          # 特定游戏类型 API
│       ├── index.ts    # 游戏 API 索引
│       └── turtlesoup.ts # 海龟汤游戏 API
├── cloud.ts            # 云函数调用封装
├── sync.ts             # 数据同步服务
└── request.ts          # 通用 HTTP 请求封装
```

### 主要模块说明

#### api 目录

包含所有 API 相关的服务，按照功能领域划分为不同的模块：

- **game.ts**: 处理通用游戏列表和游戏详情的获取
- **room.ts**: 处理房间创建、加入、退出等操作
- **games/**: 特定游戏类型的 API
  - **turtlesoup.ts**: 海龟汤游戏特定的 API
  - 未来将添加其他游戏类型如狼人杀等

#### 辅助服务

- **cloud.ts**: 封装微信小程序云开发的调用方法，简化云函数使用
- **sync.ts**: 提供数据同步服务，确保本地数据与云端保持一致
- **request.ts**: 封装 HTTP 请求，提供统一的错误处理和请求配置

### 使用示例

```typescript
// 使用通用游戏 API
import { gameAPI } from '@/services/api/game'

// 获取游戏列表
const games = await gameAPI.getGames()

// 获取特定游戏详情
const gameDetail = await gameAPI.getGameDetail('1')

// 使用特定游戏 API
import { turtleSoupAPI } from '@/services/api/games/turtlesoup'

// 获取海龟汤游戏数据
const gameData = await turtleSoupAPI.getGameData('gameId', 'player')

// 提交问题
await turtleSoupAPI.submitQuestion('gameId', '为什么海龟会喝汤？')

// 使用云函数调用封装
import { callCloudFunction } from '@/services/cloud'

// 调用自定义云函数
const result = await callCloudFunction('myFunction', { param1: 'value1' })
```

## Stores 状态管理层

状态管理层使用 Pinia 管理应用状态，提供响应式数据和状态修改方法。

### 目录结构

```
src/stores/
├── game.ts             # 游戏列表和详情状态
├── room.ts             # 房间管理状态
├── user.ts             # 用户信息和认证状态
├── tabbar.ts           # 导航栏状态
└── games/              # 特定游戏类型状态
    ├── index.ts        # 游戏状态索引
    └── turtlesoup.ts   # 海龟汤游戏状态
```

### 主要模块说明

- **game.ts**: 管理游戏列表和通用游戏详情
- **room.ts**: 管理房间创建、加入、退出等状态
- **user.ts**: 管理用户信息、登录状态、角色权限等
- **tabbar.ts**: 管理导航栏状态和导航逻辑
- **games/**: 特定游戏类型的状态管理
  - **turtlesoup.ts**: 海龟汤游戏特定的状态管理
  - 未来将添加其他游戏类型如狼人杀等

### 使用示例

```typescript
// 在组件中使用 store
import { useGameStore } from '@/stores/game'
import { useRoomStore } from '@/stores/room'
import { useUserStore } from '@/stores/user'
import { useTurtleSoupStore } from '@/stores/games/turtlesoup'

// 在组件的 setup 函数中
export default {
  setup() {
    const gameStore = useGameStore()
    const roomStore = useRoomStore()
    const userStore = useUserStore()
    const turtleSoupStore = useTurtleSoupStore()
    
    // 加载游戏列表
    gameStore.fetchGames()
    
    // 获取游戏详情
    const loadGameDetail = async (id) => {
      const game = await gameStore.getGameDetail(id)
      return game
    }
    
    // 创建房间
    const createRoom = async (roomData) => {
      // 返回创建结果
      return await roomStore.createRoom(roomData)
    }
    
    // 加载海龟汤游戏
    const loadTurtleSoupGame = async (gameId) => {
      await turtleSoupStore.loadGame(gameId, userStore.role)
    }
    
    return {
      games: gameStore.games,
      currentGame: gameStore.currentGame,
      currentRoom: roomStore.currentRoom,
      loadGameDetail,
      createRoom,
      loadTurtleSoupGame
    }
  }
}
```

## 协同工作流程

Services 和 Stores 层的协同工作流程如下：

1. **组件触发操作**：用户在 UI 组件上触发操作（如点击按钮）
2. **Store Action 被调用**：组件调用相应 Store 的 Action 处理操作
3. **Service 处理业务逻辑**：Store 调用 Service 进行 API 调用或数据处理
4. **Store 更新状态**：根据 Service 返回的结果更新 Store 的状态
5. **组件重新渲染**：由于 Store 状态变化，组件自动重新渲染

### 典型流程示例

以"用户加入房间"为例：

```typescript
// 在组件中
const joinRoom = async (roomId, password) => {
  try {
    // 1. 调用 Store Action
    const result = await roomStore.joinRoom(roomId, password)
    
    if (result.success) {
      // 4. 处理成功结果
      Taro.navigateTo({ url: `/pages/room/waiting/index?roomId=${roomId}` })
    } else {
      // 5. 处理失败结果
      Taro.showToast({ title: result.message, icon: 'none' })
    }
  } catch (error) {
    console.error('加入房间失败', error)
    Taro.showToast({ title: '加入房间失败', icon: 'none' })
  }
}

// 在 Store 中
// 2. Store Action 调用 Service
async joinRoom(roomId, password) {
  try {
    // 检查房间是否需要密码
    const checkResult = await roomAPI.checkRoomExist(roomId)
    
    if (checkResult.needPassword && !password) {
      return { success: false, message: '请输入房间密码' }
    }
    
    // 调用 Service 方法
    const result = await roomAPI.joinRoom(roomId, password)
    
    // 3. 更新 Store 状态
    if (result.success) {
      this.currentRoom = result.roomData
    }
    
    return result
  } catch (error) {
    console.error('加入房间失败', error)
    return { success: false, message: '加入房间失败' }
  }
}
```

## 扩展指南

### 添加新的 Service

1. 在 `services/api` 目录下创建新的服务文件，如 `myService.ts`
2. 实现服务方法，根据需要调用 `request.ts` 或 `cloud.ts` 中的方法
3. 导出服务对象或方法

```typescript
// services/api/myService.ts
import { callCloudFunction } from '../cloud'

export const myServiceAPI = {
  async getData(param) {
    return callCloudFunction('getMyData', { param })
  },
  
  async updateData(data) {
    return callCloudFunction('updateMyData', { data })
  }
}
```

### 添加新的 Store

1. 在 `stores` 目录下创建新的 store 文件，如 `myStore.ts`
2. 使用 Pinia 的 `defineStore` 定义 store
3. 导入并使用相应的 service

```typescript
// stores/myStore.ts
import { defineStore } from 'pinia'
import { myServiceAPI } from '@/services/api/myService'

export const useMyStore = defineStore('myStore', {
  state: () => ({
    data: null,
    loading: false,
    error: null
  }),
  
  actions: {
    async fetchData(param) {
      this.loading = true
      try {
        this.data = await myServiceAPI.getData(param)
        return this.data
      } catch (error) {
        this.error = error
        return null
      } finally {
        this.loading = false
      }
    },
    
    async updateData(newData) {
      return await myServiceAPI.updateData(newData)
    }
  }
})
```

### 添加新的游戏类型

1. 在 `services/api/games` 目录下创建新游戏的 API 文件，如 `newgame.ts`
2. 在 `stores/games` 目录下创建新游戏的 Store 文件，如 `newgame.ts`
3. 更新 `services/api/games/index.ts` 和 `stores/games/index.ts` 导出新添加的模块

## 最佳实践

### Services 层

1. **单一职责**：每个服务应专注于单一的功能领域
2. **错误处理**：在服务中妥善处理错误，并提供有意义的错误信息
3. **Mock 数据**：为开发和测试提供 mock 数据
4. **类型安全**：使用 TypeScript 类型定义确保类型安全
5. **接口一致性**：保持 API 接口的一致性，便于使用

### Stores 层

1. **状态最小化**：只存储必要的状态
2. **计算属性**：使用 getters 派生状态，避免数据冗余
3. **Action 封装**：在 actions 中封装业务逻辑，不要在组件中直接调用服务
4. **持久化**：必要时使用本地存储持久化关键状态
5. **状态重置**：提供清除状态的方法，避免状态污染

### 协作规范

1. **命名规范**：使用一致的命名规范，如服务使用 `xxxAPI`，store 使用 `useXxxStore`
2. **导入路径**：使用 `@/` 别名导入，保持导入路径简洁
3. **注释**：为核心方法和复杂逻辑添加注释
4. **版本控制**：将相关的 service 和 store 变更放在同一个提交中
5. **测试**：为关键服务和 store 编写测试

## 结语

通过合理使用 Services 和 Stores 架构，LineJoy 项目实现了清晰的关注点分离和职责划分，使得代码更易维护和扩展。在开发新功能时，请遵循本指南中的建议，保持项目的一致性和可维护性。

如有任何疑问，请参考项目中的现有实现作为范例，或与团队成员讨论。
